###############################################################################
#                                                                              
# Rohde & Schwarz GmbH & Co. KG                                                
# 1MA294 Sigfox Signal Generation and Analysis                                 
# Production Testing with Sigfox Devices                                       
# Version 1.0, Andreas Mandel (Dept. 1MAA/RSD)                                 
#                                                                              
###############################################################################

import visa
import math

# Variables #

ul_frq  = 868130000 # Uplink Frequency in Hz                                   
dl_frq  = 869525000 # Downlink Frequency in Hz                                 

att_in  =   0.00    # External Attenuation (Input) in dB                       
enp     =  16.00    # Expected Nominal Power in dBm                            
fsp     =   1.25    # Frequency Span in MHz                                    
fftl    =   1024    # FFT Length (Number of Samples)                           
thr     = -30.00    # Trigger Threshold in dBm                                 
tout    =  20.00    # Trigger Timeout in s                                     

att_out =   0.00    # External Attenuation (Output) in dB                      
lev     = -30.00    # Level (RMS) in dBm                                       
dga     =   0.00    # Digital Gain in dB                                       

# Arbitrary Waveform File #

arbfile = "C:\ProgramData\Rohde-Schwarz\CMW\Data\Waveform\KV687_600bps_2GFSK_SIGFOX_Waveform.wv"

# User Information #

print("----------------------------------------------------------------------")
print("\nRohde & Schwarz GmbH & Co. KG")
print("1MA294 - Sigfox Signal Generation and Analysis")
print("Production Testing with Sigfox Devices\n")
print("----------------------------------------------------------------------")

# R&S CMW: General Setup #

print("----------------------------------------------------------------------")
print("R&S CMW100: General Setup.")
print("----------------------------------------------------------------------")
    
CMW.write("*RST")                                                               # Reset Device.                      
CMW.write("*CLS")                                                               # Clear Status.                      
CMW.ask("*OPT?")                                                                # Option Query.                      
CMW.ask("*IDN?")                                                                # Query ID String.                   

# R&S CMW: General Purpose Generator #

print("----------------------------------------------------------------------")
print("R&S CMW100: General Purpose Generator.")
print("----------------------------------------------------------------------")

# Select Connectors and Signal Paths:
CMW.write("ROUT:GPRF:GEN:SCEN:SAL R118, TX11")

# Activate/Deactivates RF Connectors:
CMW.write("CONF:GPRF:GEN:CMWS:USAG:TX:ALL R118, OFF, ON, OFF, OFF, OFF, OFF, OFF, OFF")

CMW.write("SOUR:GPRF:GEN:RFS:EATT " + str(att_out))                             # Define External Attenuation.       
CMW.write("SOUR:GPRF:GEN:RFS:FREQ " + str(dl_frq))                              # Define Center Frequency (UL).      
CMW.write("SOUR:GPRF:GEN:RFS:LEV " + str(lev))                                  # Define Base RMS Level.             
CMW.write("SOUR:GPRF:GEN:RFS:DGA " + str(dga))                                  # Define Digital Gain.               

CMW.write("SOUR:GPRF:GEN:BBM ARB")                                              # Set Baseband Mode to ARB.          
CMW.write("SOUR:GPRF:GEN:ARB:REP CONT")                                         # Set Reputation to Continuous.      
CMW.write("SOUR:GPRF:GEN:ARB:FILE '" + str(arbfile) + "'")                      # Select ARB File.                   
CMW.write("SOUR:GPRF:GEN:STAT ON")                                              # Turn ON the Generator.             

# User Information #

print("----------------------------------------------------------------------")
print("Executing Script finished!")
print("----------------------------------------------------------------------")