###############################################################################
#
# Rohde & Schwarz GmbH & Co. KG
# 1MA294 Sigfox Signal Generation and Analysis
# Setting R&S SMBV as Sigfox Base Station Transmitter
# Version 1.0, Andreas Mandel (Dept. 1MAA/RSD)
#
###############################################################################

import visa
import time

# Variables #

dlfrq  = 869525000  # Downlink Frequency in Hz
rflvl  = -30        # Power Level in dBm
srate  = 600        # Symbol Rate in Symb/s
frqdev = 800        # Frequency Deviation in Hz
fparam = 0.35       # Roll-Off Factor for Filter: 0.15 to 10E4

# User Information #

print("----------------------------------------------------------------------")
print("\nRohde & Schwarz GmbH & Co. KG")
print("1MA294 - Sigfox Signal Generation and Analysis")
print("Setting R&S SMBV as Sigfox Base Station Transmitter\n")
print("----------------------------------------------------------------------")

# R&S SMBV Configuration #

print("----------------------------------------------------------------------")
print("R&S SMBV Configuration.")
print("----------------------------------------------------------------------\n")
 
# Reset Device
SMBV.write("*RST")

# Clear Status
SMBV.write("*CLS")

# Option Query
SMBV.ask("*OPT?") 

# Query ID String
SMBV.ask("*IDN?")                                                                

# Define Frequeny Level
SMBV.write("SOUR:FREQ " + str(dlfrq))

# Define Power Level
SMBV.write("SOUR:POW " + str(rflvl))                                          

# Select Data Source: Data List
SMBV.write("BB:DM:SOUR DLIS")
           
# Create Data List File: 'Sigfox_0'
SMBV.write("BB:DM:DLIS:SEL 'Sigfox_0'")

# Wait for configuring Generator...
SMBV.ask("*OPC?")

# Sigfox Downlink Frame: AA AA B2 27 1F 20 41 84 32 68 C5 BA 53 AE 79 E7 F6 DD 9B
SMBV.write("BB:DM:DLIS:DATA     1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,1,0,0,1,0,0,0,1,0,0,1,1,1,0,0,0,1,1,1,1,1,0,0,1,0")
SMBV.write("BB:DM:DLIS:DATA:APP 0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,0,0,1,0,0,0,0,1,1,0,0,1,0,0,1,1,0,1,0,0,0,1,1,0,0,0,1,0,1")
SMBV.write("BB:DM:DLIS:DATA:APP 1,0,1,1,1,0,1,0,0,1,0,1,0,0,1,1,1,0,1,0,1,1,1,0,0,1,1,1,1,0,0,1,1,1,1,0,0,1,1,1,1,1,1,1")
SMBV.write("BB:DM:DLIS:DATA:APP 0,1,1,0,1,1,0,1,1,1,0,1,1,0,0,1,1,0,1,1")

# Wait for configuring Generator...
SMBV.ask("*OPC?")

# Define Symbol Rate
SMBV.write("BB:DM:SRAT " + str(srate))

# Disable Coding
SMBV.write("BB:DM:COD OFF")

# Modulation Type: FSK2 | FSK4
SMBV.write("BB:DM:FORM FSK2")

# Set Frequency Deviation for FSK
SMBV.write("BB:DM:FSK:DEV " + str(frqdev))

# Filter Type: GAUS
SMBV.write("BB:DM:FILT:TYPE GAUS")

# Set Roll-Off Factor for Filter
SMBV.write("BB:DM:FILT:PAR:GAUS " + str(fparam))

# Enable Digital Modulation
SMBV.write("BB:DM:STAT ON")

# Activate RF Signal Output
SMBV.write("OUTP:STAT ON")

# Goto Local: Manual Control
SMBV.write("&GTL")